django-addanother provides you with *add another* buttons for forms outside the Django administration interface. It also provides an optional integration with
django-select2_.

See documentation_ for details.

.. _django-select2: http://django-select2.readthedocs.org/
.. _documentation: http://django-addanother.readthedocs.org/
